package com.ruoyi.frequency.integralrecord.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.enums.IntegralDetailEnums;
import com.ruoyi.frequency.integralrecord.entity.IntegralRecord;
import com.ruoyi.frequency.wallerecord.model.result.WalletRecordCount;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.PageBasic;
import com.ruoyi.vo.UserVo;

import java.math.BigDecimal;
import java.util.List;

/**
 * 积分记录Service接口
 *
 * @author liwenlong
 * @date 2024-01-29
 */
public interface IntegralRecordService extends IService<IntegralRecord>
{
    /**
     * 查询积分记录
     *
     * @param id 积分记录主键
     * @return 积分记录
     */
    public IntegralRecord selectIntegralRecordById(Long id);

    /**
     * 查询积分记录列表
     *
     * @param integralRecord 积分记录
     * @return 积分记录集合
     */
    public List<IntegralRecord> selectIntegralRecordList(IntegralRecord integralRecord);

    /**
     * 新增积分记录
     *
     * @param integralRecord 积分记录
     * @return 结果
     */
    public int insertIntegralRecord(IntegralRecord integralRecord);

    /**
     * 修改积分记录
     *
     * @param integralRecord 积分记录
     * @return 结果
     */
    public int updateIntegralRecord(IntegralRecord integralRecord);

    /**
     * 批量删除积分记录
     *
     * @param ids 需要删除的积分记录主键集合
     * @return 结果
     */
    public int deleteIntegralRecordByIds(Long[] ids,Integer delFlag);

    /**
     * 修改积分
     * @param userVo
     * @param id
     * @param integral
     * @param integralDetailEnums
     */
    void updateIntegral(UserVo userVo, Long id, BigDecimal integral, IntegralDetailEnums integralDetailEnums,String remark);

    /**
     * 积分明细
     * @param req
     * @param userVo
     * @return
     */
    ResponseData integralPage(PageBasic req, UserVo userVo);

    WalletRecordCount statistics(IntegralRecord integralRecord);
}
